» Sketch Hunt Stickers

Plugin Hunt is a community of product enthusiasts. Submissions are accepted by our most active members, specifically those that have been invited by others in the community.

Learn more about invites

.

# Sketch Hunt Stickers

The very first item of Sketch Hunt swag is here. We put poll out to our users, asking if they’d prefer buttons or stickers and stickers won by a small margin. Inspired by the responses, we turned to our trusted buddies at Sticker Mule to create a 3×3 inch sticker to celebrate the growing community that is Sketch Hunt. Order one today!

U.S. Residents: $4.00 (with free USPS first class shipping) Too expensive?

Outside the U.S. but interested in buying a sticker? Contact Us

No comments yet.

x
Sign in to Sketch Hunt or create an account
Sign in with Facebook
Sign in with Twitter

Or, login normally

We will never post to Twitter or Facebook without your permission.

### Add to Collection

### Add product media

Enter the URL of an image or YouTube video: